import { defineConfig } from 'vite';
import react from '@vitejs/plugin-react';
import { resolve } from 'path';
import fs from 'fs';

// Dynamically get all entries including global assets
const getEntries = () => {
  const activitiesDir = resolve(__dirname, 'src/activities');
  const globalAssetsDir = resolve(__dirname, 'src/assets');
  const chapters = fs.readdirSync(activitiesDir);
  const inputs = {};

  // Add global assets
  if (fs.existsSync(globalAssetsDir)) {
    const globalAssets = fs.readdirSync(globalAssetsDir);
    globalAssets.forEach(asset => {
      const assetPath = resolve(globalAssetsDir, asset);
      inputs[`global-assets/${asset}`] = assetPath;
    });
  }

  // Add chapter entries and their assets
  chapters.forEach((chapter) => {
    // Add HTML entry point
    const htmlPath = resolve(activitiesDir, chapter, 'index.html');
    if (fs.existsSync(htmlPath)) {
      inputs[`${chapter}/index`] = htmlPath;
    }

    // Add chapter-specific assets
    const chapterAssetsDir = resolve(activitiesDir, chapter, 'assets');
    if (fs.existsSync(chapterAssetsDir)) {
      const assets = fs.readdirSync(chapterAssetsDir);
      assets.forEach(asset => {
        const assetPath = resolve(chapterAssetsDir, asset);
        inputs[`${chapter}/assets/${asset}`] = assetPath;
      });
    }
  });

  return inputs;
};

export default defineConfig({
  build: {
    rollupOptions: {
      input: getEntries(),
      output: {
        // Handle JavaScript files
        entryFileNames: (chunkInfo) => {
          const name = chunkInfo.name.replace('/index', '');
          if (name.startsWith('global-assets')) {
            return 'src/assets/[name].js';
          }
          return `src/activities/${name}/${name}.js`;
        },
        
        // Handle chunks
        chunkFileNames: (chunkInfo) => {
          return `src/activities/${chunkInfo.name}/chunks/[hash].js`;
        },
        
        // Handle assets
        assetFileNames: (assetInfo) => {
          const filePath = assetInfo.name;
          if (!filePath) return 'src/assets/[name].[ext]';

          // Handle global assets
          if (filePath.includes('global-assets')) {
            const fileName = filePath.split('/').pop();
            return `src/assets/${fileName}`;
          }

          // Handle chapter-specific assets
          const pathParts = filePath.split('/');
          const chapterIndex = pathParts.indexOf('activities') + 1;
          
          if (chapterIndex > 0 && chapterIndex < pathParts.length) {
            const chapter = pathParts[chapterIndex];
            const assetPath = pathParts.slice(chapterIndex + 1).join('/');
            return `src/activities/${chapter}/${assetPath}`;
          }
          
          return `src/assets/[name].[ext]`;
        }
      },
    },
    outDir: 'dist',
    emptyOutDir: true,
    assetsDir: '',
  },
  plugins: [react()],
});